game = {}

function game:NewGame(w, h)
	self.is_active = true
	menu.is_active = false
	self.win_animation = false
	self.can_click = true
	self.is_over = false
	
	self.w = w
	self.h = h
	
	for x = 1, w do
		self[x] = {}
		
		for y = 1, h do
			self[x][y] = tile.create(x, y)
		end
	end

	self.sweepie = {
		x = self[1][1].start_x + self.w * tile.size + 2,
		y = self[1][1].start_y - 120 + tile.size,
		sweep_left = true,
		start_x = self[1][1].start_x,
		end_y = self[self.w][self.h].start_y + tile.size
	}
	
	local sweep_sound = menu.sound.sweep
	
	if sweep_sound:isPlaying() then
		sweep_sound:stop()
	end
	
	if menu.sound.explosion:isPlaying() then
		menu.sound.explosion:stop()
	end
end

function game:AnimateSweepie()
	local sweepie = self.sweepie
	local sweep_left = sweepie.sweep_left
	local start_tile, end_tile = self[1][1], self[self.w][self.h]
	local start_x = sweepie.start_x
	local end_y = sweepie.end_y
		
	love.graphics.setColor(255, 255, 255)
	love.graphics.draw(menu.pictures[1], menu.pictures.sweepie, sweepie.x, sweepie.y, 0, sweep_left and 1 or -1, 1)
		
	if sweepie.y + 120 <= end_y then
		if sweep_left then
			if sweepie.x + 60 < start_x then
				sweepie.sweep_left = not sweep_left
				sweepie.y = sweepie.y + tile.size
			else
				sweepie.x = sweepie.x - 8
				
				for x = 1, self.w do
					for y = 1, self.h do
						local t = self[x][y]
						
						if t.start_x + tile.size >= sweepie.x and sweepie.y + 120 - tile.size == t.start_y  then
							t.start_x = t.start_x - 8
						end
					end
				end
			end
		else
			if sweepie.x > self.w * tile.size + start_x then
				sweepie.sweep_left = not sweep_left
				sweepie.y = sweepie.y + tile.size
			else
				sweepie.x = sweepie.x + 8
				
				for x = 1, self.w do
					for y = 1, self.h do
						local t = self[x][y]
						
						if t.start_x + tile.size <= sweepie.x + tile.size and sweepie.y + 120 - tile.size == t.start_y  then
							t.start_x = t.start_x + 8
						else
							menu.sound.cheer:play()
						end
					end
				end
			end
		end
	else
		local sweep_sound = menu.sound.sweep
		local winner = menu.pictures.you_win
		local winner_w, winner_h = winner:getDimensions()
		
		love.graphics.setColor(255, 255, 255)
		love.graphics.draw(winner, w / 2 - winner_w / 2, h / 2 - winner_h / 2)
		
		if sweep_sound:isPlaying() then
			menu.sound.sweep:stop()
		end
	end
end

function game:Draw()
	if self.win_animation then
		self:AnimateSweepie()
	end

	for x = 1, self.w do
		for y = 1, self.h do
			self[x][y]:Draw()
		end
	end
	
	if not self.can_click then  --meaning that the game is over
		local img = menu.pictures.game_over
		local img_w, img_h = img:getDimensions()
		love.graphics.setColor(255, 255, 255)
		love.graphics.draw(img, w / 2 - img_w / 2, h / 2 - img_h / 2)
	end
end

function game:SaveGame()
	if not self.is_active then
		return 
	end
	
	if self.win_animation then	
		return
	end
	
	if self.is_over then
		return
	end
	
	local file = love.filesystem.newFile("save.lua")

	file:open("w")
	file:write("game.w = " .. self.w .. "\n")
	file:write("game.h = " .. self.h .. "\n")

	for x = 1, self.w do
		for y = 1, self.h do
			local t = self[x][y]
			file:write(string.format("game[%s][%s] = setmetatable({x = %s, y = %s, pressed = %s, marked = %s, bomb = %s, start_x = %s, start_y = %s", x, y, x, y, t.pressed, t.marked, t.bomb, t.start_x, t.start_y) .. "}, tile)" .. "\n")
		end
	end
	
	file:close()
	print("file saved")
end

function game:LoadGame()  --work on this, 
	if not love.filesystem.exists("save.lua") then
		print("file doesn't exist")
		return
	end

	self.is_active = true
	menu.is_active = false
	self.win_animation = false
	self:NewGame(15, 15)
	love.filesystem.load("save.lua")()
end

function game:GameOver()
	self.can_click = false
	self.is_over = true
	menu.sound.explosion:play()
end

function game:WinCheck()
	for x = 1, self.w do
		for y = 1, self.h do
			local t = self[x][y]
			
			if t.bomb and not t.marked then
				return false
			elseif not t.bomb then
				if t.marked or not t.pressed then
					return false
				end
			end
		end
	end
	
	self:OnWin()
end

function game:OnWin()
	self.win_animation = true
	
	for x = 1, self.w do
		for y = 1, self.h do
			local t = self[x][y]
			t.pressed = true
			t.marked = false
		end
	end
	
	menu.sound.sweep:play()
	menu.sound.sweep:setLooping(true)
end

function game:DrawGameOver()
	
end