menu = {}
menu.options = {}
menu.is_active = true

menu.pictures = {
	love.graphics.newImage("sweepie.jpg"),
	love.graphics.newImage("bar.png"),
	love.graphics.newImage("logo.png"),
	game_over = love.graphics.newImage("game_over.png"),
	you_win = love.graphics.newImage("you_win.png")
}

menu.pictures.sweepie = love.graphics.newQuad(0, 0, 60, 120, 60, 120)

menu.sound = {
	love.audio.newSource("song.mp3", "stream"),
	love.audio.newSource("next.mp3", "static"),
	sweep = love.audio.newSource("sweep.wav", "static"),
	explosion = love.audio.newSource("explosion.mp3", "static"),
	cheer = love.audio.newSource("cheer.wav", "static"),
	press = love.audio.newSource("press.wav", "static")
}

local press = menu.sound.press
press:setVolume(0.2)

menu.sound[1]:setVolume(0.05)
menu.sound[1]:play()
menu.sound[1]:setLooping(true)

menu.sound.explosion:setVolume(0.3)
menu.sound.cheer:setVolume(0.2)

function menu:AddOption(text, on_select)
	local option = {}
	option.text = text
	option.on_select = on_select
	option.is_selected = false
	
	self.options[#self.options + 1] = option
	
	if #self.options == 1 then
		option.is_selected = true
	end
end

function menu:Draw()
	love.graphics.setColor(0, 0, 0)
	love.graphics.rectangle("fill", 0, 0, love.graphics.getDimensions())

	love.graphics.setColor(255, 255, 255)
	love.graphics.draw(self.pictures[1], w / 2 - self.pictures[1]:getWidth() / 4, 0, 0, 0.5, 0.5)
	
	love.graphics.draw(self.pictures[2],0, h - self.pictures[2]:getHeight())
	
	love.graphics.draw(self.pictures[3], w / 2 - self.pictures[3]:getWidth() / 2)

	for i = 1, #self.options do
		local option = self.options[i]
		
		if option.is_selected then
			love.graphics.setColor(0, 155, 50)
		else
			love.graphics.setColor(0, 0, 0)
		end
		
		love.graphics.print(option.text, w / 3, 30 * i + 120)
	end
end

function menu:GetSelected()
	for i = 1, #self.options do
		local option = self.options[i]
		
		if option.is_selected then
			return option
		end
	end
end

function menu:Next(value)
	menu.sound[2]:stop()
	
	for i = 1, #self.options do
		local option = self.options[i]
		
		if option.is_selected then
			menu.sound[2]:play()
			option.is_selected = false
			local value2 = i + value
			local next = (value2 > #self.options and self.options[1]) or value2 < 1 and self.options[#self.options] or self.options[value2]

			next.is_selected = true
			break
		end
	end
end

menu:AddOption("New Game", function()
	game:NewGame(15, 15)
	press:stop()
	press:play()
end)

menu:AddOption("Save", function()
	game:SaveGame()
	press:stop()
	press:play()
end)

menu:AddOption("Load", function()
	game:LoadGame()
	press:stop()
	press:play()
end)

menu:AddOption("Exit", function()
	love.event.quit()
	press:stop()
	press:play()
end)



