tile = {}
tile.__index = tile
tile.size = 30
tile.color = {r = 155, g = 155, b = 155}

tile.number_colors = {
	{r = 60, g = 255, b = 255},
	{r = 50, g = 255, b = 180},
	{r = 255, g = 100, b = 100},
	{r = 130, g = 10, b = 200},
	{r = 150, g = 155, b = 100},
	{r = 180, g = 200, b = 80},
	{r = 250, g = 200, b = 20},
	{r = 220, g = 220, b = 220}
}

function tile.create(x, y)
	local t = setmetatable({}, tile)
	t.x = x
	t.y = y
	t.pressed = false
	t.marked = false
	
	local size = t.size
	local x_size = t.x * size - size
	local y_size = t.y * size - size
	local x_offset = size * game.w / 2
	local y_offset = size * game.h / 2
	
	t.start_x = w / 2 - x_offset + x_size
	t.start_y = h / 2 - y_offset + y_size

	local random = math.random(1, 7)
	
	if random == 7 then
		t.bomb = true
	end
	
	return t
end

function tile:Draw()	
	local size = self.size

	if self.bomb then
		love.graphics.setColor(255, 255, 255)
		love.graphics.draw(menu.pictures[2], self.start_x, self.start_y, 0, 0.2, 0.2)
	else
		local count = 0
		
		for x = -1, 1 do
			if game[x + self.x] then
				for y = -1, 1 do
					local t = game[x + self.x][y + self.y]
					
					if t and t.bomb and t ~= self then
						count = count + 1
					end
				end
			end
		end
		
		if not game.win_animation then
			if count > 0  then
				local color = self.number_colors[count]
				love.graphics.setColor(color.r, color.g, color.b)
				love.graphics.print(count, self.start_x + size / 2 - size / 4, self.start_y + size / 2 - size / 4)
			end
		end
	end
		
	if not self.pressed then
		love.graphics.setColor(155, 155, 155)
		love.graphics.rectangle("fill", self.start_x, self.start_y, size, size)

		love.graphics.setColor(0, 0, 0)
		love.graphics.rectangle("line", self.start_x, self.start_y, size, size)
	end
	
	if self.marked then
		love.graphics.setColor(255, 0, 0)
		love.graphics.rectangle("fill", self.start_x, self.start_y, size, size)
	end
end

function tile:GetBombCount()
	local count = 0
	
	for x = -1, 1 do		
		if game[x + self.x] then
			for y = -1, 1 do
				local t = game[x + self.x][y + self.y]
				
				if t and t.bomb and t ~= self then
					count = count + 1
				end
			end
		end
	end
	
	return count
end

function tile:ShowAdjacent()
	for x = -1, 1 do		
		if game[x + self.x] then
			for y = -1, 1 do
				local t = game[x + self.x][y + self.y]
				
				if t then
					t:OnLeftClick()
				end
			end
		end
	end
end

function tile:OnLeftClick()
	if not game.can_click then
		return
	end

	if self.pressed or self.marked then
		return
	end

	self.pressed = true
	
	if self.bomb then
		game:GameOver()
	else
		if self:GetBombCount() == 0 then
			for x = -1, 1 do
				if game[x + self.x] then
					for y = -1, 1 do
						local t = game[x + self.x][y + self.y]
						
						if t then
							t.pressed = true
						
							if t ~= self and t:GetBombCount() == 0 then
								t:ShowAdjacent()
							end
						end
					end
				end
			end
		end
	end
	
	game:WinCheck()
end

function tile:OnRightClick()
	if not game.can_click then
		return
	end

	if self.pressed then
		return
	end

	self.marked = not self.marked
	game:WinCheck()
end

